@@ -1,4 +1,4 @@
-//! rlimit - A simple wrapper for `getrlimit` and `setrlimit`.
+//! rlimit - Resource limits.
 //!
 //! # Examples
 //!
@@ -30,7 +30,15 @@
 //! ```
 //!
 //! ## Increase NOFILE limit
-//! See the example [nofile](https://github.com/Nugine/rlimit/tree/v0.6.0/examples/nofile.rs).
+//! See the example [nofile](https://github.com/Nugine/rlimit/tree/v0.6.1/examples/nofile.rs).
+//!
+//! You can also use the tools in [`rlimit::utils`][`crate::utils`].
+//!
+//! ```no_run
+//! use rlimit::utils::increase_nofile_limit;
+//! increase_nofile_limit(10240).unwrap();
+//! increase_nofile_limit(u64::MAX).unwrap();
+//! ```
 //!
 //! # Troubleshoot
 //!
@@ -40,6 +48,9 @@
 //! via sysctl (`kern.maxfilesperproc`). Failing to discover this secret stricter hard limit will
 //! cause the call to setrlimit to fail.
 //!
+//! [`rlimit::utils::increase_nofile_limit`][`crate::utils::increase_nofile_limit`]
+//! respects `kern.maxfilesperproc`.
+//!
 
 #![deny(
     missing_docs,
@@ -64,3 +75,5 @@ group! {
     #[doc(inline)]
     pub use self::unix::*;
 }
+
+pub mod utils;
